/*
 *  dvtext.h
 *
 *  Copyright (C) 2004 David Simmons
 *
 *  This file is part of dvtext.
 *
 *  dvtext is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  dvtext is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with dvtext; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef _DVTEXT_H
#define _DVTEXT_H

#include <ft2build.h>
#include FT_FREETYPE_H

#define DEFAULT_FONT		"FreeSansBold.ttf"
#define DEFAULT_POINTSIZE	32
#define DEFAULT_TEXTTYPE	TEXTTYPE_TITLE
#define DEFAULT_TITLE_LEADIN	30
#define DEFAULT_TITLE_FADEIN	30
#define DEFAULT_TITLE_SOLID	(30*4)
#define DEFAULT_TITLE_FADEOUT	30
#define DEFAULT_TITLE_LEADOUT	30
#define DEFAULT_YPOS		240

#define DEFAULT_DPI		96
#define	DEFAULT_OUTPUT_FILENAME	"out.avi"

#define NTSC_WIDTH		720
#define NTSC_HEIGHT		480
#define PAL_WIDTH		720
#define PAL_HEIGHT		576
#define DV_FRAME_SIZE_NTSC	120000
#define DV_FRAME_SIZE_PAL	144000

#define DEFAULT_SCROLL_YSPACING	15

typedef struct textface_s {
	/* identifying characteristics */
	char *fontname;
	int pointsize;

	/* The freetype font face */
	FT_Face face;

	struct textface_s *next;
} textface_t;

typedef struct textitem_s {
	char *string;

	/* stuff that the user specifies */
	char *fontname;
	int pointsize;
	int ypos;

	/* stuff that we resolve later */
	textface_t *textface;
	int pixel_width;

	struct textitem_s *next;
} textitem_t;

typedef enum {
	TEXTTYPE_UNKNOWN = 0,
	TEXTTYPE_TITLE,
	TEXTTYPE_SCROLL
} texttype_t;

typedef struct dvtext_s {

	/* data */
	textface_t *textface_list;
	textitem_t *textitem_list;
	texttype_t texttype;

	/* title params */
	int title_leadin;
	int title_fadein;
	int title_solid;
	int title_fadeout;
	int title_leadout;
	
	/* scroll params */

	/* handles */
	FT_Library freetype;

} dvtext_t;

typedef enum {
	NTSC = 0,
	PAL,
	SECAM
} standardtype_t;

typedef struct standard_s {
	
	/* data */
	float framerate;
	int width;
	int height;
	int framesize;
	
} standard_t;

#endif /* _DVTEXT_H */

